#!/bin/bash

# Copyright (c) 2013 Cloudera, Inc. All rights reserved.

# Time marker for both stderr and stdout
date; date 1>&2

cloudera_config=`dirname $0`
cloudera_config=`cd "$cloudera_config/../common"; pwd`
. ${cloudera_config}/cloudera-config.sh

# Attempt to find Java and place it in JAVA_HOME. The catalina.sh script expects
# to find it there.
locate_java_home

# Load the parcel environment
source_parcel_environment

set -x

echo "using $CDH_VERSION as CDH_VERSION"
export SOLR_HOME=$CDH_SOLR_HOME

# This script expects the following env vars to be set by CM server:
# SOLR_SERVER_OPTS (optional): Any additional java cmd line opts to be passed to Solr servers
# SOLR_SERVICE_ZNODE: ZooKeeper znode used to store info about collections
# SOLR_HTTP_PORT
# SOLR_ADMIN_PORT
# SOLR_LOG_DIR
# SOLR_DATA_DIR
# SOLR_HDFS_HOME

if [ "solrinit" = "$1" ]; then
  exec $CDH_SOLR_HOME/bin/solrctl.sh --zk $SOLR_SERVICE_ZNODE init
fi
export CATALINA_BASE=$CDH_SOLR_HOME/server
export CATALINA_TMPDIR=$PWD/temp
export CATALINA_OUT=$SOLR_LOG_DIR/solr.out
export CATALINA_PID=$PWD/solr.pid

OPTIONS="$SOLR_SERVER_OPTS"
OPTIONS="$OPTIONS -DzkHost=$SOLR_SERVICE_ZNODE"
OPTIONS="$OPTIONS -Dhost=$SOLR_HOST"
OPTIONS="$OPTIONS -Djetty.port=$SOLR_HTTP_PORT"
OPTIONS="$OPTIONS -Dsolr.host=$SOLR_HOST"
OPTIONS="$OPTIONS -Dsolr.port=$SOLR_HTTP_PORT"
OPTIONS="$OPTIONS -Dlog4j.configuration=file:///$CONF_DIR/log4j.properties"
OPTIONS="$OPTIONS -Dsolr.log=$SOLR_LOG_DIR"
OPTIONS="$OPTIONS -Dsolr.admin.port=$SOLR_ADMIN_PORT"
OPTIONS="$OPTIONS -Dsolr.solr.home=$SOLR_DATA_DIR"
OPTIONS="$OPTIONS -Dsolr.hdfs.home=$SOLR_HDFS_HOME"
OPTIONS="$OPTIONS -Dsolr.hdfs.confdir=$CONF_DIR/hadoop-conf"
OPTIONS="$OPTIONS -Djava.net.preferIPv4Stack=true" # Disable IPv6.
OPTIONS="$OPTIONS -Dsolr.solrxml.location=zookeeper"

# Add options for kerberos
if [ -n "$SOLR_KERBEROS_PRINCIPAL" ] ; then
  OPTIONS="$OPTIONS -Dsolr.hdfs.security.kerberos.enabled=true"
  OPTIONS="$OPTIONS -Dsolr.hdfs.security.kerberos.keytabfile=$CONF_DIR/solr.keytab"
  OPTIONS="$OPTIONS -Dsolr.hdfs.security.kerberos.principal=$SOLR_KERBEROS_PRINCIPAL"
fi

export CATALINA_OPTS="$OPTIONS"

# Create temp directory for Catalina
mkdir -p $CATALINA_TMPDIR

exec $TOMCAT_HOME/bin/catalina.sh run

